==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiGui/QAccessibleImageInterface_shell.cpp <==
#include "QAccessibleImageInterface_shell.h"
#include <QtJambi/Cast>

void deleter_QAccessibleImageInterface(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAccessibleImageInterface")
    QAccessibleImageInterface *_ptr = reinterpret_cast<QAccessibleImageInterface *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAccessibleImageInterface_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAccessibleImageInterface_shell) ); }

jmethodID QAccessibleImageInterface_shell::__shell_javaMethod(int pos) const { return QAccessibleImageInterface_shell::__shell()->javaMethod(typeid(QAccessibleImageInterface), pos); }

// emitting (writeShellConstructor)
QAccessibleImageInterface_shell::QAccessibleImageInterface_shell()
    : QAccessibleImageInterface()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessibleImageInterface::QAccessibleImageInterface_shell()", QAccessibleImageInterface_shell::__shell())
    QAccessibleImageInterface_shell::__shell()->constructed(typeid(QAccessibleImageInterface));
}

// emitting (writeShellDestructor)
QAccessibleImageInterface_shell::~QAccessibleImageInterface_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAccessibleImageInterface::~QAccessibleImageInterface()", QAccessibleImageInterface_shell::__shell())
    QAccessibleImageInterface_shell::__shell()->destructed(typeid(QAccessibleImageInterface));
}

void QAccessibleImageInterface_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAccessibleImageInterface_shell*>(ptr)->QAccessibleImageInterface_shell::__shell()->tryDeleteShell(typeid(QAccessibleImageInterface));
}

// emitting Virtual overrides (virtualFunctions)
QString QAccessibleImageInterface_shell::imageDescription() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QAccessibleImageInterface::", QAccessibleImageInterface_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QString  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QAccessibleImageInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jstring __java_return_value = jstring(__jni_env->CallObjectMethod(__java_this, method_id));
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QString >(__jni_env, __java_return_value);
                } else {
                    QAccessibleImageInterface_shell::__shell()->warnForMethod("QAccessibleImageInterface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAccessibleImageInterface::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QString();
        }
    }else{
        return QString();
    }
}

QPoint QAccessibleImageInterface_shell::imagePosition() const
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QAccessibleImageInterface::", QAccessibleImageInterface_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QPoint  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QAccessibleImageInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QPoint >(__jni_env, __java_return_value);
                } else {
                    QAccessibleImageInterface_shell::__shell()->warnForMethod("QAccessibleImageInterface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAccessibleImageInterface::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QPoint();
        }
    }else{
        return QPoint();
    }
}

QSize QAccessibleImageInterface_shell::imageSize() const
{
    if(jmethodID method_id = __shell_javaMethod(2)){
        QTJAMBI_JAVA_METHOD_CALL("QAccessibleImageInterface::", QAccessibleImageInterface_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QSize  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QAccessibleImageInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QSize >(__jni_env, __java_return_value);
                } else {
                    QAccessibleImageInterface_shell::__shell()->warnForMethod("QAccessibleImageInterface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAccessibleImageInterface::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSize();
        }
    }else{
        return QSize();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jstring QAccessibleImageInterface_access::__qt_imageDescription(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QAccessibleImageInterface::imageDescription() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QAccessibleImageInterface::imageDescription() const.";
    } else {
        QString __qt_return_value = imageDescription();
        return qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }
}

jobject QAccessibleImageInterface_access::__qt_imagePosition(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QAccessibleImageInterface::imagePosition() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QAccessibleImageInterface::imagePosition() const.";
    } else {
        QPoint __qt_return_value = imagePosition();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

jobject QAccessibleImageInterface_access::__qt_imageSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QAccessibleImageInterface::imageSize() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QAccessibleImageInterface::imageSize() const.";
    } else {
        QSize __qt_return_value = imageSize();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new 
void __qt_construct_QAccessibleImageInterface_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QAccessibleImageInterface *__qt_this = new(__qtjambi_ptr) QAccessibleImageInterface_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QAccessibleImageInterface_shell
void __qt_destruct_QAccessibleImageInterface(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAccessibleImageInterface")
    reinterpret_cast<QAccessibleImageInterface_shell*>(ptr)->~QAccessibleImageInterface_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAccessibleImageInterface::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleImageInterface_00024Impl_initialize_1native__Lio_qt_gui_QAccessibleImageInterface_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessibleImageInterface::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessibleImageInterface_0, sizeof(QAccessibleImageInterface_shell), typeid(QAccessibleImageInterface), true, &deleter_QAccessibleImageInterface, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAccessibleImageInterface::imageDescription()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleImageInterface_00024Impl_00024ConcreteWrapper_imageDescription_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QAccessibleImageInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QAccessibleImageInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleImageInterface::imageDescription()const", __qt_this)
        __java_return_value = static_cast<const QAccessibleImageInterface_access*>(__qt_this)->__qt_imageDescription(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QAccessibleImageInterface::imagePosition()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleImageInterface_00024Impl_00024ConcreteWrapper_imagePosition_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QAccessibleImageInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QAccessibleImageInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleImageInterface::imagePosition()const", __qt_this)
        __java_return_value = static_cast<const QAccessibleImageInterface_access*>(__qt_this)->__qt_imagePosition(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QAccessibleImageInterface::imageSize()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleImageInterface_00024Impl_00024ConcreteWrapper_imageSize_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QAccessibleImageInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QAccessibleImageInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleImageInterface::imageSize()const", __qt_this)
        __java_return_value = static_cast<const QAccessibleImageInterface_access*>(__qt_this)->__qt_imageSize(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAccessibleImageInterface(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QAccessibleImageInterface>("QAccessibleImageInterface", "io/qt/gui/QAccessibleImageInterface");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "imageDescription", "()Ljava/lang/String;", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "imagePosition", "()Lio/qt/core/QPoint;", FunctionInfo::Abstract),
        FunctionInfo(/* 2 */ "imageSize", "()Lio/qt/core/QSize;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QAccessibleImageInterface, {
        ConstructorInfo(&__qt_construct_QAccessibleImageInterface_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAccessibleImageInterface);
    registerSizeOfShell(typeId, sizeof(QAccessibleImageInterface_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QAccessibleImageInterface* _object = dynamic_cast<QAccessibleImageInterface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QAccessibleImageInterface *object = reinterpret_cast<QAccessibleImageInterface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QAccessibleImageInterface *object = reinterpret_cast<const QAccessibleImageInterface *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QAccessibleImageInterface_shell.cpp <==
#include "QAccessibleImageInterface_shell.h"
#include <QtJambi/Cast>

void deleter_QAccessibleImageInterface(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAccessibleImageInterface")
    QAccessibleImageInterface *_ptr = reinterpret_cast<QAccessibleImageInterface *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAccessibleImageInterface_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAccessibleImageInterface_shell) ); }

jmethodID QAccessibleImageInterface_shell::__shell_javaMethod(int pos) const { return QAccessibleImageInterface_shell::__shell()->javaMethod(typeid(QAccessibleImageInterface), pos); }

// emitting (writeShellConstructor)
QAccessibleImageInterface_shell::QAccessibleImageInterface_shell()
    : QAccessibleImageInterface()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessibleImageInterface::QAccessibleImageInterface_shell()", QAccessibleImageInterface_shell::__shell())
    QAccessibleImageInterface_shell::__shell()->constructed(typeid(QAccessibleImageInterface));
}

// emitting (writeShellDestructor)
QAccessibleImageInterface_shell::~QAccessibleImageInterface_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAccessibleImageInterface::~QAccessibleImageInterface()", QAccessibleImageInterface_shell::__shell())
    QAccessibleImageInterface_shell::__shell()->destructed(typeid(QAccessibleImageInterface));
}

void QAccessibleImageInterface_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAccessibleImageInterface_shell*>(ptr)->QAccessibleImageInterface_shell::__shell()->tryDeleteShell(typeid(QAccessibleImageInterface));
}

// emitting Virtual overrides (virtualFunctions)
QString QAccessibleImageInterface_shell::imageDescription() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QAccessibleImageInterface::", QAccessibleImageInterface_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QString  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QAccessibleImageInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jstring __java_return_value = jstring(__jni_env->CallObjectMethod(__java_this, method_id));
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QString>(__jni_env, __java_return_value);
                } else {
                    QAccessibleImageInterface_shell::__shell()->warnForMethod("QAccessibleImageInterface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAccessibleImageInterface::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QString();
        }
    }else{
        return QString();
    }
}

QPoint QAccessibleImageInterface_shell::imagePosition() const
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QAccessibleImageInterface::", QAccessibleImageInterface_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QPoint  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QAccessibleImageInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QPoint >(__jni_env, __java_return_value);
                } else {
                    QAccessibleImageInterface_shell::__shell()->warnForMethod("QAccessibleImageInterface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAccessibleImageInterface::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QPoint();
        }
    }else{
        return QPoint();
    }
}

QSize QAccessibleImageInterface_shell::imageSize() const
{
    if(jmethodID method_id = __shell_javaMethod(2)){
        QTJAMBI_JAVA_METHOD_CALL("QAccessibleImageInterface::", QAccessibleImageInterface_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QSize  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QAccessibleImageInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QSize >(__jni_env, __java_return_value);
                } else {
                    QAccessibleImageInterface_shell::__shell()->warnForMethod("QAccessibleImageInterface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAccessibleImageInterface::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSize();
        }
    }else{
        return QSize();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jstring QAccessibleImageInterface_access::__qt_imageDescription_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QAccessibleImageInterface::imageDescription() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QAccessibleImageInterface::imageDescription() const.";
    } else {
        QString __qt_return_value = imageDescription();
        return qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }
}

jobject QAccessibleImageInterface_access::__qt_imagePosition_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QAccessibleImageInterface::imagePosition() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QAccessibleImageInterface::imagePosition() const.";
    } else {
        QPoint __qt_return_value = imagePosition();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

jobject QAccessibleImageInterface_access::__qt_imageSize_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QAccessibleImageInterface::imageSize() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QAccessibleImageInterface::imageSize() const.";
    } else {
        QSize __qt_return_value = imageSize();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new QAccessibleImageInterface()
void __qt_construct_QAccessibleImageInterface(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAccessibleImageInterface()")
    Q_UNUSED(__java_arguments)
    QAccessibleImageInterface *__qt_this = new(__qtjambi_ptr) QAccessibleImageInterface_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QAccessibleImageInterface::QAccessibleImageInterface()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleImageInterface_00024Impl_initialize_1native__Lio_qt_gui_QAccessibleImageInterface_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessibleImageInterface::QAccessibleImageInterface()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessibleImageInterface, sizeof(QAccessibleImageInterface_shell), typeid(QAccessibleImageInterface), true, &deleter_QAccessibleImageInterface, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QAccessibleImageInterface_shell
void __qt_destruct_QAccessibleImageInterface(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAccessibleImageInterface")
    reinterpret_cast<QAccessibleImageInterface_shell*>(ptr)->~QAccessibleImageInterface_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAccessibleImageInterface::imageDescription()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleImageInterface_00024Impl_00024ConcreteWrapper_imageDescription_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QAccessibleImageInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QAccessibleImageInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleImageInterface::imageDescription()const", __qt_this)
        __java_return_value = static_cast<const QAccessibleImageInterface_access*>(__qt_this)->__qt_imageDescription_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QAccessibleImageInterface::imagePosition()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleImageInterface_00024Impl_00024ConcreteWrapper_imagePosition_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QAccessibleImageInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QAccessibleImageInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleImageInterface::imagePosition()const", __qt_this)
        __java_return_value = static_cast<const QAccessibleImageInterface_access*>(__qt_this)->__qt_imagePosition_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QAccessibleImageInterface::imageSize()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleImageInterface_00024Impl_00024ConcreteWrapper_imageSize_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QAccessibleImageInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QAccessibleImageInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleImageInterface::imageSize()const", __qt_this)
        __java_return_value = static_cast<const QAccessibleImageInterface_access*>(__qt_this)->__qt_imageSize_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAccessibleImageInterface(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QAccessibleImageInterface>("QAccessibleImageInterface", "io/qt/gui/QAccessibleImageInterface");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "imageDescription", "()Ljava/lang/String;", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "imagePosition", "()Lio/qt/core/QPoint;", FunctionInfo::Abstract),
        FunctionInfo(/* 2 */ "imageSize", "()Lio/qt/core/QSize;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QAccessibleImageInterface, {
        ConstructorInfo(&__qt_construct_QAccessibleImageInterface, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAccessibleImageInterface);
    registerSizeOfShell(typeId, sizeof(QAccessibleImageInterface_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QAccessibleImageInterface* _object = dynamic_cast<QAccessibleImageInterface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QAccessibleImageInterface *object = reinterpret_cast<QAccessibleImageInterface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QAccessibleImageInterface *object = reinterpret_cast<const QAccessibleImageInterface *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
